chrome.webNavigation.onCompleted.addListener(async (details) => {
  const restrictedUrls = ['chrome://', 'chrome-extension://'];

  if (restrictedUrls.some(url => details.url.startsWith(url))) {
    return; // Skip restricted URLs
  }

  const { css, applyToSubdomains, darkMode } = await new Promise((resolve) => {
    chrome.storage.local.get(['css', 'applyToSubdomains', 'darkMode'], resolve);
  });

  if (css) {
    const url = new URL(details.url);
    const domain = url.hostname;
    const shouldApply = applyToSubdomains || domain === url.hostname;

    if (shouldApply) {
      chrome.scripting.executeScript({
        target: { tabId: details.tabId },
        function: injectCSS,
        args: [css, darkMode]
      });
    }
  }
}, { url: [{ hostContains: '.' }] });

function injectCSS(css, darkMode) {
  if (document.getElementById('custom-css')) {
    document.getElementById('custom-css').remove();
  }
  const style = document.createElement('style');
  style.id = 'custom-css';
  style.textContent = css + (darkMode ? `
    /* Dark Mode Styles */
    body {
      background-color: #121212 !important;
      color: #e0e0e0 !important;
    }
    a {
      color: #bb86fc !important;
    }
    header, footer, main, section, article, aside, div, span {
      background-color: #1e1e1e !important;
      color: #e0e0e0 !important;
    }
    input, textarea, select, button {
      background-color: #333 !important;
      color: #e0e0e0 !important;
      border: 1px solid #555 !important;
    }
    nav, .header, .footer, .sidebar {
      background-color: #1e1e1e !important;
    }
    p, h1, h2, h3, h4, h5, h6 {
      color: #e0e0e0 !important;
    }
    * {
      background-color: #121212 !important;
      color: #e0e0e0 !important;
    }
  ` : '');
  document.head.appendChild(style);
}
