document.addEventListener('DOMContentLoaded', () => {
  const cssInput = document.getElementById('cssInput');
  const applyToSubdomains = document.getElementById('applyToSubdomains');
  const saveCss = document.getElementById('saveCss');
  const removeCss = document.getElementById('removeCss');
  const darkModeToggle = document.getElementById('darkModeToggle');

  // Load existing CSS and settings
  chrome.storage.local.get(['css', 'applyToSubdomains'], (result) => {
    cssInput.value = result.css || '';
    applyToSubdomains.checked = result.applyToSubdomains || false;
  });

  // Save CSS
  saveCss.addEventListener('click', () => {
    const css = cssInput.value;
    const subdomains = applyToSubdomains.checked;
    chrome.storage.local.set({ css, applyToSubdomains: subdomains }, () => {
      alert('CSS saved and applied!');
      // Refresh the current page to apply CSS immediately
      chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
        chrome.scripting.executeScript({
          target: { tabId: tabs[0].id },
          function: injectCSS,
          args: [css]
        });
      });
    });
  });

  // Remove CSS
  removeCss.addEventListener('click', () => {
    chrome.storage.local.remove(['css', 'applyToSubdomains'], () => {
      alert('CSS removed!');
      // Remove CSS from the current page
      chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
        chrome.scripting.executeScript({
          target: { tabId: tabs[0].id },
          function: removeCSS
        });
      });
    });
  });

  // Toggle dark mode
  darkModeToggle.addEventListener('change', () => {
    chrome.tabs.query({ active: true, currentWindow: true }, (tabs) => {
      chrome.tabs.sendMessage(tabs[0].id, {
        action: darkModeToggle.checked ? 'applyDarkMode' : 'removeDarkMode'
      });
    });
  });
});

// Function to inject CSS
function injectCSS(css) {
  if (document.getElementById('custom-css')) {
    document.getElementById('custom-css').remove();
  }
  const style = document.createElement('style');
  style.id = 'custom-css';
  style.textContent = css;
  document.head.appendChild(style);
}

// Function to remove CSS
function removeCSS() {
  const styleElement = document.getElementById('custom-css');
  if (styleElement) {
    styleElement.remove();
  }
}
